@@ -9,6 +9,7 @@
 #include <signal.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <stdio.h>
 
 static const char* FILE_NAME = "Sys/Signal.c";
 
@@ -98,30 +99,26 @@ int32_t SPVM__Sys__Signal__ualarm(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__Signal__new_SIG_DFL(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Signal__SIG_DFL(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
   
-  void* obj_signal_handler = env->new_object_by_name(env, stack, "Sys::Signal::Handler::Default", &error_id, __func__, __FILE__, __LINE__);
+  void* obj_handler = env->new_pointer_object_by_name(env, stack, "Sys::Signal::Handler", SIG_DFL, &error_id, __func__, __FILE__, __LINE__);
   if (error_id) { return error_id; }
   
-  env->set_pointer(env, stack, obj_signal_handler, SIG_DFL);
-  
-  stack[0].oval = obj_signal_handler;
+  stack[0].oval = obj_handler;
   
   return 0;
 }
 
-int32_t SPVM__Sys__Signal__new_SIG_IGN(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Signal__SIG_IGN(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
   
-  void* obj_signal_handler = env->new_object_by_name(env, stack, "Sys::Signal::Handler::Ignore", &error_id, __func__, __FILE__, __LINE__);
+  void* obj_handler = env->new_pointer_object_by_name(env, stack, "Sys::Signal::Handler", SIG_IGN, &error_id, __func__, __FILE__, __LINE__);
   if (error_id) { return error_id; }
   
-  env->set_pointer(env, stack, obj_signal_handler, SIG_IGN);
-  
-  stack[0].oval = obj_signal_handler;
+  stack[0].oval = obj_handler;
   
   return 0;
 }
@@ -138,14 +135,6 @@ int32_t SPVM__Sys__Signal__signal(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$handler must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t is_valid_handler =
-    env->is_type_by_name(env, stack, obj_handler, "Sys::Signal::Handler::Default", 0)
-    || env->is_type_by_name(env, stack, obj_handler, "Sys::Signal::Handler::Ignore", 0);
-  
-  if (!is_valid_handler) {
-    return env->die(env, stack, "$handler must be a Sys::Signal::Handler::Default object or a Sys::Signal::Handler::Ignore object,.", __func__, FILE_NAME, __LINE__);
-  }
-  
   void* handler = env->get_pointer(env, stack, obj_handler);
   
   void* old_handler = signal(signum, handler);
@@ -155,6 +144,59 @@ int32_t SPVM__Sys__Signal__signal(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
+  void* obj_old_handler = env->new_pointer_object_by_name(env, stack, "Sys::Signal::Handler", old_handler, &error_id, __func__, __FILE__, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_old_handler;
+  
   return 0;
 }
 
+static int32_t signal_write_fds[64] = {0};
+
+static void signal_hander_io(int32_t signal) {
+  int32_t signal_write_fd = signal_write_fds[signal];
+  
+  int32_t write_length = write(signal_write_fd, &signal, sizeof(int32_t));
+}
+
+int32_t SPVM__Sys__Signal__SIG_IO(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* obj_handler = env->new_pointer_object_by_name(env, stack, "Sys::Signal::Handler", &signal_hander_io, &error_id, __func__, __FILE__, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_handler;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Signal__signal_io(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  int32_t signum = stack[0].ival;
+  
+  if (!(signum < 64)) {
+    return env->die(env, stack, "$signum must be less than 64.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+  }
+  
+  int32_t signal_write_fd = stack[1].ival;
+  
+  signal_write_fds[signum] = signal_write_fd;
+  
+  void* old_handler = signal(signum, &signal_hander_io);
+  
+  if (old_handler == SIG_ERR) {
+    env->die(env, stack, "[System Error]signal failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  void* obj_old_handler = env->new_pointer_object_by_name(env, stack, "Sys::Signal::Handler", old_handler, &error_id, __func__, __FILE__, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_old_handler;
+  
+  return 0;
+}
