@@ -18,499 +18,499 @@ C<Sys::Signal::Constant> is a L<SPVM> module.
 
 =head2 BUS_ADRALN
 
-  static method BUS_ADRALN : int ();
+C<static method BUS_ADRALN : int ();>
 
 Gets the value of C<BUS_ADRALN>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 BUS_ADRERR
 
-  static method BUS_ADRERR : int ();
+C<static method BUS_ADRERR : int ();>
 
 Gets the value of C<BUS_ADRERR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 BUS_MCEERR_AO
 
-  static method BUS_MCEERR_AO : int ();
+C<static method BUS_MCEERR_AO : int ();>
 
 Gets the value of C<BUS_MCEERR_AO>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 BUS_MCEERR_AR
 
-  static method BUS_MCEERR_AR : int ();
+C<static method BUS_MCEERR_AR : int ();>
 
 Gets the value of C<BUS_MCEERR_AR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 BUS_MCERR_
 
-  static method BUS_MCERR_ : int ();
+C<static method BUS_MCERR_ : int ();>
 
 Gets the value of C<BUS_MCERR_>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 BUS_OBJERR
 
-  static method BUS_OBJERR : int ();
+C<static method BUS_OBJERR : int ();>
 
 Gets the value of C<BUS_OBJERR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 CLD_CONTINUED
 
-  static method CLD_CONTINUED : int ();
+C<static method CLD_CONTINUED : int ();>
 
 Gets the value of C<CLD_CONTINUED>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 CLD_DUMPED
 
-  static method CLD_DUMPED : int ();
+C<static method CLD_DUMPED : int ();>
 
 Gets the value of C<CLD_DUMPED>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 CLD_EXITED
 
-  static method CLD_EXITED : int ();
+C<static method CLD_EXITED : int ();>
 
 Gets the value of C<CLD_EXITED>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 CLD_KILLED
 
-  static method CLD_KILLED : int ();
+C<static method CLD_KILLED : int ();>
 
 Gets the value of C<CLD_KILLED>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 CLD_STOPPED
 
-  static method CLD_STOPPED : int ();
+C<static method CLD_STOPPED : int ();>
 
 Gets the value of C<CLD_STOPPED>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 CLD_TRAPPED
 
-  static method CLD_TRAPPED : int ();
+C<static method CLD_TRAPPED : int ();>
 
 Gets the value of C<CLD_TRAPPED>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_FLTDIV
 
-  static method FPE_FLTDIV : int ();
+C<static method FPE_FLTDIV : int ();>
 
 Gets the value of C<FPE_FLTDIV>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_FLTINV
 
-  static method FPE_FLTINV : int ();
+C<static method FPE_FLTINV : int ();>
 
 Gets the value of C<FPE_FLTINV>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_FLTOVF
 
-  static method FPE_FLTOVF : int ();
+C<static method FPE_FLTOVF : int ();>
 
 Gets the value of C<FPE_FLTOVF>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_FLTRES
 
-  static method FPE_FLTRES : int ();
+C<static method FPE_FLTRES : int ();>
 
 Gets the value of C<FPE_FLTRES>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_FLTSUB
 
-  static method FPE_FLTSUB : int ();
+C<static method FPE_FLTSUB : int ();>
 
 Gets the value of C<FPE_FLTSUB>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_FLTUND
 
-  static method FPE_FLTUND : int ();
+C<static method FPE_FLTUND : int ();>
 
 Gets the value of C<FPE_FLTUND>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_INTDIV
 
-  static method FPE_INTDIV : int ();
+C<static method FPE_INTDIV : int ();>
 
 Gets the value of C<FPE_INTDIV>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FPE_INTOVF
 
-  static method FPE_INTOVF : int ();
+C<static method FPE_INTOVF : int ();>
 
 Gets the value of C<FPE_INTOVF>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 FUTEX_WAIT
 
-  static method FUTEX_WAIT : int ();
+C<static method FUTEX_WAIT : int ();>
 
 Gets the value of C<FUTEX_WAIT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_BADSTK
 
-  static method ILL_BADSTK : int ();
+C<static method ILL_BADSTK : int ();>
 
 Gets the value of C<ILL_BADSTK>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_COPROC
 
-  static method ILL_COPROC : int ();
+C<static method ILL_COPROC : int ();>
 
 Gets the value of C<ILL_COPROC>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_ILLADR
 
-  static method ILL_ILLADR : int ();
+C<static method ILL_ILLADR : int ();>
 
 Gets the value of C<ILL_ILLADR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_ILLOPC
 
-  static method ILL_ILLOPC : int ();
+C<static method ILL_ILLOPC : int ();>
 
 Gets the value of C<ILL_ILLOPC>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_ILLOPN
 
-  static method ILL_ILLOPN : int ();
+C<static method ILL_ILLOPN : int ();>
 
 Gets the value of C<ILL_ILLOPN>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_ILLTRP
 
-  static method ILL_ILLTRP : int ();
+C<static method ILL_ILLTRP : int ();>
 
 Gets the value of C<ILL_ILLTRP>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_PRVOPC
 
-  static method ILL_PRVOPC : int ();
+C<static method ILL_PRVOPC : int ();>
 
 Gets the value of C<ILL_PRVOPC>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 ILL_PRVREG
 
-  static method ILL_PRVREG : int ();
+C<static method ILL_PRVREG : int ();>
 
 Gets the value of C<ILL_PRVREG>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 POLL_ERR
 
-  static method POLL_ERR : int ();
+C<static method POLL_ERR : int ();>
 
 Gets the value of C<POLL_ERR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 POLL_HUP
 
-  static method POLL_HUP : int ();
+C<static method POLL_HUP : int ();>
 
 Gets the value of C<POLL_HUP>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 POLL_IN
 
-  static method POLL_IN : int ();
+C<static method POLL_IN : int ();>
 
 Gets the value of C<POLL_IN>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 POLL_MSG
 
-  static method POLL_MSG : int ();
+C<static method POLL_MSG : int ();>
 
 Gets the value of C<POLL_MSG>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 POLL_OUT
 
-  static method POLL_OUT : int ();
+C<static method POLL_OUT : int ();>
 
 Gets the value of C<POLL_OUT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 POLL_PRI
 
-  static method POLL_PRI : int ();
+C<static method POLL_PRI : int ();>
 
 Gets the value of C<POLL_PRI>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_ASYNCIO
 
-  static method SI_ASYNCIO : int ();
+C<static method SI_ASYNCIO : int ();>
 
 Gets the value of C<SI_ASYNCIO>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_KERNEL
 
-  static method SI_KERNEL : int ();
+C<static method SI_KERNEL : int ();>
 
 Gets the value of C<SI_KERNEL>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_MESGQ
 
-  static method SI_MESGQ : int ();
+C<static method SI_MESGQ : int ();>
 
 Gets the value of C<SI_MESGQ>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_QUEUE
 
-  static method SI_QUEUE : int ();
+C<static method SI_QUEUE : int ();>
 
 Gets the value of C<SI_QUEUE>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_SIGIO
 
-  static method SI_SIGIO : int ();
+C<static method SI_SIGIO : int ();>
 
 Gets the value of C<SI_SIGIO>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_TIMER
 
-  static method SI_TIMER : int ();
+C<static method SI_TIMER : int ();>
 
 Gets the value of C<SI_TIMER>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_TKILL
 
-  static method SI_TKILL : int ();
+C<static method SI_TKILL : int ();>
 
 Gets the value of C<SI_TKILL>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SI_USER
 
-  static method SI_USER : int ();
+C<static method SI_USER : int ();>
 
 Gets the value of C<SI_USER>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 TRAP_BRANCH
 
-  static method TRAP_BRANCH : int ();
+C<static method TRAP_BRANCH : int ();>
 
 Gets the value of C<TRAP_BRANCH>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 TRAP_BRKPT
 
-  static method TRAP_BRKPT : int ();
+C<static method TRAP_BRKPT : int ();>
 
 Gets the value of C<TRAP_BRKPT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 TRAP_HWBKPT
 
-  static method TRAP_HWBKPT : int ();
+C<static method TRAP_HWBKPT : int ();>
 
 Gets the value of C<TRAP_HWBKPT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 TRAP_TRACE
 
-  static method TRAP_TRACE : int ();
+C<static method TRAP_TRACE : int ();>
 
 Gets the value of C<TRAP_TRACE>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGABRT
 
-  static method SIGABRT : int ();
+C<static method SIGABRT : int ();>
 
 Gets the value of C<SIGABRT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGALRM
 
-  static method SIGALRM : int ();
+C<static method SIGALRM : int ();>
 
 Gets the value of C<SIGALRM>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGBUS
 
-  static method SIGBUS : int ();
+C<static method SIGBUS : int ();>
 
 Gets the value of C<SIGBUS>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGCHLD
 
-  static method SIGCHLD : int ();
+C<static method SIGCHLD : int ();>
 
 Gets the value of C<SIGCHLD>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGCONT
 
-  static method SIGCONT : int ();
+C<static method SIGCONT : int ();>
 
 Gets the value of C<SIGCONT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGFPE
 
-  static method SIGFPE : int ();
+C<static method SIGFPE : int ();>
 
 Gets the value of C<SIGFPE>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGHUP
 
-  static method SIGHUP : int ();
+C<static method SIGHUP : int ();>
 
 Gets the value of C<SIGHUP>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGILL
 
-  static method SIGILL : int ();
+C<static method SIGILL : int ();>
 
 Gets the value of C<SIGILL>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGINT
 
-  static method SIGINT : int ();
+C<static method SIGINT : int ();>
 
 Gets the value of C<SIGINT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGIO
 
-  static method SIGIO : int ();
+C<static method SIGIO : int ();>
 
 Gets the value of C<SIGIO>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGKILL
 
-  static method SIGKILL : int ();
+C<static method SIGKILL : int ();>
 
 Gets the value of C<SIGKILL>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGPIPE
 
-  static method SIGPIPE : int ();
+C<static method SIGPIPE : int ();>
 
 Gets the value of C<SIGPIPE>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGPROF
 
-  static method SIGPROF : int ();
+C<static method SIGPROF : int ();>
 
 Gets the value of C<SIGPROF>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGPWR
 
-  static method SIGPWR : int ();
+C<static method SIGPWR : int ();>
 
 Gets the value of C<SIGPWR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGQUIT
 
-  static method SIGQUIT : int ();
+C<static method SIGQUIT : int ();>
 
 Gets the value of C<SIGQUIT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGRTMAX
 
-  static method SIGRTMAX : int ();
+C<static method SIGRTMAX : int ();>
 
 Gets the value of C<SIGRTMAX>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGRTMIN
 
-  static method SIGRTMIN : int ();
+C<static method SIGRTMIN : int ();>
 
 Gets the value of C<SIGRTMIN>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGSEGV
 
-  static method SIGSEGV : int ();
+C<static method SIGSEGV : int ();>
 
 Gets the value of C<SIGSEGV>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGSTKFLT
 
-  static method SIGSTKFLT : int ();
+C<static method SIGSTKFLT : int ();>
 
 Gets the value of C<SIGSTKFLT>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGSTOP
 
-  static method SIGSTOP : int ();
+C<static method SIGSTOP : int ();>
 
 Gets the value of C<SIGSTOP>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGSYS
 
-  static method SIGSYS : int ();
+C<static method SIGSYS : int ();>
 
 Gets the value of C<SIGSYS>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGTERM
 
-  static method SIGTERM : int ();
+C<static method SIGTERM : int ();>
 
 Gets the value of C<SIGTERM>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGTRAP
 
-  static method SIGTRAP : int ();
+C<static method SIGTRAP : int ();>
 
 Gets the value of C<SIGTRAP>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGTSTP
 
-  static method SIGTSTP : int ();
+C<static method SIGTSTP : int ();>
 
 Gets the value of C<SIGTSTP>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGTTIN
 
-  static method SIGTTIN : int ();
+C<static method SIGTTIN : int ();>
 
 Gets the value of C<SIGTTIN>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGTTOU
 
-  static method SIGTTOU : int ();
+C<static method SIGTTOU : int ();>
 
 Gets the value of C<SIGTTOU>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGURG
 
-  static method SIGURG : int ();
+C<static method SIGURG : int ();>
 
 Gets the value of C<SIGURG>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGUSR1
 
-  static method SIGUSR1 : int ();
+C<static method SIGUSR1 : int ();>
 
 Gets the value of C<SIGUSR1>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGUSR2
 
-  static method SIGUSR2 : int ();
+C<static method SIGUSR2 : int ();>
 
 Gets the value of C<SIGUSR2>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGVTALRM
 
-  static method SIGVTALRM : int ();
+C<static method SIGVTALRM : int ();>
 
 Gets the value of C<SIGVTALRM>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGWINCH
 
-  static method SIGWINCH : int ();
+C<static method SIGWINCH : int ();>
 
 Gets the value of C<SIGWINCH>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGXCPU
 
-  static method SIGXCPU : int ();
+C<static method SIGXCPU : int ();>
 
 Gets the value of C<SIGXCPU>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIGXFSZ
 
-  static method SIGXFSZ : int ();
+C<static method SIGXFSZ : int ();>
 
 Gets the value of C<SIGXFSZ>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIG_DFL
 
-  static method SIG_DFL : int ();
+C<static method SIG_DFL : int ();>
 
 Gets the value of C<SIG_DFL>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIG_ERR
 
-  static method SIG_ERR : int ();
+C<static method SIG_ERR : int ();>
 
 Gets the value of C<SIG_ERR>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
 =head2 SIG_IGN
 
-  static method SIG_IGN : int ();
+C<static method SIG_IGN : int ();>
 
 Gets the value of C<SIG_IGN>. If the value is not defined in the system, an exception is thrown with the error code set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.
 
